==> leadconduit-integration-leadconduit-1.0.0.tgz: package/lib/to_flow.js <==
url = require('url');
flatten = require('flat');
querystring = require('querystring');

const request = (vars) => {

  let body = flatten(vars.lead);

  for(let key in body) {
    let value = body[key];
    if(value) body[key] = value.toString();
  }

  for(let key in vars.custom) {
    let value = vars.custom[key];
    if(value) body[key] = value;
  }

  body = querystring.stringify(body);

  let url = '';

  switch(process.env.NODE_ENV) {
    case 'staging':
     url = `https://next.staging.leadconduit.com/flows/${vars.flow_id}/sources/${vars.account.id}/submit`;
     break;
    case 'development':
      url = `http://leadconduit.localhost/flows/${vars.flow_id}/sources/${vars.account.id}/submit`;
      break;
    default:
      url = `https://next.leadconduit.com/flows/${vars.flow_id}/sources/${vars.account.id}/submit`;
  }

  return {
    body: body,
    url: url,
    method: 'POST',
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
      Accept: 'application/json'
    }
  }

};

request.variables = () => {
  return [
    { name: 'flow_id', type: 'string', required: true, description: 'The ID of the destination flow' },
    { name: 'custom.*', type: 'wildcard', required: false }
  ];
};

const response = (vars, req, res) => {

  if(!res || !res.body) {
    return {
      outcome: 'error',
      reason: 'unknown response'
    }
  }

  try {
    let parsed = JSON.parse(res.body);

    if (parsed.message) {
      return {
        outcome: 'error',
        reason: parsed.message
      }
    }

    return {
      outcome: parsed.outcome,
      reason: parsed.reason,
      lead: {
        id: parsed.lead.id
      }
    };
  }
  catch (e) {
    return {
      outcome: 'error',
      reason: 'unable to parse response'
    }
  }

};

response.variables = () => {
  return [
    { name: 'outcome', type: 'string', description: 'The outcome of the lead' },
    { name: 'reason', type: 'string', description: 'If the outcome was not success, this is the reason' },
    { name: 'lead.id', type: 'string', description: `The lead's ID` }
  ]
};

const validate = (vars) => {

  if (!vars.flow_id) return 'flow ID must not be blank';

};

module.exports = {
  name: 'To Flow',
  request: request,
  response: response,
  validate: validate
};

==> leadconduit-integration-leadconduit-1.2.7.tgz: package/lib/to_flow.js <==
const flatten = require('flat');
const querystring = require('querystring');

const request = (vars) => {

  let body = flatten(vars.lead);

  for(let key in body) {
    let value = body[key];
    if(value) body[key] = value.toString();
  }

  for(let key in vars.custom) {
    let value = vars.custom[key];
    if(value) body[key] = value;
  }
  
  if (vars.price)
    body.price = vars.price.valueOf();
  else
    body.price = 0;

  body = querystring.stringify(body);

  let url = '';

  switch(process.env.NODE_ENV) {
    case 'staging':
      url = `https://next.staging.leadconduit.com/flows/${vars.flow_id}/sources/${vars.account.id}/submit`;
      break;
    case 'development':
      url = `http://leadconduit.localhost/flows/${vars.flow_id}/sources/${vars.account.id}/submit`;
      break;
    default:
      url = `https://next.leadconduit.com/flows/${vars.flow_id}/sources/${vars.account.id}/submit`;
  }

  return {
    body: body,
    url: url,
    method: 'POST',
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded',
      Accept: 'application/json'
    }
  };

};

request.variables = () => {
  return [
    { name: 'flow_id', type: 'string', required: true, description: 'The ID of the destination flow' },
    { name: 'price', type: 'number', description: 'The price of the lead' },
    { name: 'custom.*', type: 'wildcard', required: false }
  ];
};

const response = (vars, req, res) => {

  const price = vars.price || 0;

  if(!res || !res.body) {
    return {
      outcome: 'error',
      reason: 'unknown response',
      price,
    };
  }

  try {
    let parsed = JSON.parse(res.body);

    if (parsed.message) {
      return {
        outcome: 'error',
        reason: parsed.message,
        price
      };
    }

    return {
      outcome: parsed.outcome,
      reason: parsed.reason,
      price, 
      lead: {
        id: parsed.lead.id
      },
    };
  }
  catch (e) {
    return {
      outcome: 'error',
      reason: 'unable to parse response',
      price
    };
  }

};

response.variables = () => {
  return [
    { name: 'outcome', type: 'string', description: 'The outcome of the lead' },
    { name: 'reason', type: 'string', description: 'If the outcome was not success, this is the reason' },
    { name: 'lead.id', type: 'string', description: `The lead's ID` },
    { name: 'price', type: 'number', description: 'The price of the lead' }
  ];
};

const validate = (vars) => {

  if (!vars.flow_id) return 'flow ID must not be blank';

};

module.exports = {
  name: 'To Flow',
  request: request,
  response: response,
  validate: validate
};
